@@ -23,10 +23,13 @@ class ConverterNode(Node):
         self.converter = converter
 
         @self.on_event("startup")
-        @repeat_every(seconds=5, raise_exceptions=True, wait_first=False)
+        @repeat_every(seconds=5, raise_exceptions=True, wait_first=True)
         async def check_state():
             if not self.skip_check_state:
-                await self.check_state()
+                try:
+                    await self.check_state()
+                except:
+                    logging.error('could not check state. Is loop reachable?')
 
     async def convert_model(self, organization: str, project: str, model_id: str):
         await self.converter.convert(organization, project, model_id)
@@ -39,9 +42,16 @@ class ConverterNode(Node):
             return
         self.status.state = State.Running
 
-        model = await self.find_model_to_convert()
+        try:
+            model = await self.find_model_to_convert()
+        except:
+            logging.error(f'could not find models for conversion')
         if model:
-            await self.convert_model(model.organization, model.project, model.model_id)
+            try:
+                await self.convert_model(model.organization, model.project, model.model_id)
+            except:
+                logging.error(f'could not convert model {model}')
+
         self.status.state = State.Idle
 
     async def find_model_to_convert(self) -> ModelInformation:
